﻿using System;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using Telerik.Web.UI;
using System.Collections.Generic;

namespace ShList.SPlist
{
    class AppointmentInfo
    {
        private readonly string _id;
        private string _subject;
        private DateTime _start;
        private DateTime _end;
        private string _recurrenceRule;
        private string _recurrenceParentId;
        private string _reminder;
        private string _continent;
        private int? _userID;

        public string ID
        {
            get { return _id; }
        }

        public string Subject
        {
            get { return _subject; }
            set { _subject = value; }
        }

        public DateTime Start
        {
            get { return _start; }
            set { _start = value; }
        }

        public DateTime End
        {
            get { return _end; }
            set { _end = value; }
        }

        public string RecurrenceRule
        {
            get { return _recurrenceRule; }
            set { _recurrenceRule = value; }
        }

        public string RecurrenceParentID
        {
            get { return _recurrenceParentId; }
            set { _recurrenceParentId = value; }
        }

        public int? UserID
        {
            get { return _userID; }
            set { _userID = value; }
        }

        public string Reminder
        {
            get { return _reminder; }
            set { _reminder = value; }
        }

        public string Continent
        {
            get { return _continent; }
            set { _continent = value; }
        }

        private AppointmentInfo()
        {
            _id = Guid.NewGuid().ToString();
        }

        public AppointmentInfo(string subject, DateTime start, DateTime end,
            string recurrenceRule, string recurrenceParentID, string reminder,string continent, int? userID)
            : this()
        {
            _subject = subject;
            _start = start;
            _end = end;
            _recurrenceRule = recurrenceRule;
            _recurrenceParentId = recurrenceParentID;
            _reminder = reminder;
            _continent = continent;
            _userID = userID;
        }

        public AppointmentInfo(Appointment source)
            : this()
        {
            CopyInfo(source);
        }

        public void CopyInfo(Appointment source)
        {
            Subject = source.Subject;
            Start = source.Start;
            End = source.End;
            RecurrenceRule = source.RecurrenceRule;
            if (source.RecurrenceParentID != null)
            {
                RecurrenceParentID = source.RecurrenceParentID.ToString();
            }

            if (!String.IsNullOrEmpty(Reminder))
            {
                Reminder = source.Reminders[0].ToString();
            }

           


            Resource user = source.Resources.GetResourceByType("User");
            if (user != null)
            {
                UserID = (int?)user.Key;
            }
            else
            {
                UserID = null;
            }
        }
    }

    public partial class SPlistUserControl : UserControl
    {
        private const string AppointmentsKey = "Telerik.Web.Examples.Scheduler.BindToList.CS.Apts";

        private List<AppointmentInfo> Appointments
        {
            get
            {
                List<AppointmentInfo> sessApts = new List<AppointmentInfo>();
                List<AppointmentInfo> sessApts = Session[AppointmentsKey] as List<AppointmentInfo>;
                if (sessApts == null)
                {
                    sessApts = new List<AppointmentInfo>();
                   Session[AppointmentsKey] = sessApts;
                }

                return sessApts;
            }
        }

        private ScriptManager EnsureScriptManager()
        {
            ScriptManager sm = ScriptManager.GetCurrent(Page);
            if (sm == null)
            {
                if (Page.Form != null)
                {
                    sm = new ScriptManager();
                    sm.ID = Page.Form.ID + "_ScriptManager";
                    Page.Form.Controls.Add(sm);
                }
            }

            return sm;
        }

        protected override void OnInit(EventArgs e)
        {
            base.OnInit(e);

            EnsureScriptManager();
            EnsureChildControls();

            RadAjaxManager ajaxManager = RadAjaxManager.GetCurrent(this.Page);
            if (ajaxManager == null)
            {
                ajaxManager = new RadAjaxManager();
                ajaxManager.ID = "RadAjaxManager1";
                Controls.Add(ajaxManager);
                this.Page.Items.Add(typeof(RadAjaxManager), ajaxManager);
            }
            ajaxManager.AjaxSettings.AddAjaxSetting(RadScheduler1, RadScheduler1);

            if (!IsPostBack)
            {
                Session.Remove(AppointmentsKey);

                InitializeResources();
                InitializeAppointments();
            }

            RadScheduler1.DataSource = Appointments;
        }


        private void EnsureChildControls(){
            RadScheduler1.EnableEmbeddedScripts = false;
          ScriptManager scriptManager = ScriptManager.GetCurrent(Page);
          if (scriptManager != null)
          {
              string telerikAssembly = typeof(RadScheduler).Assembly.FullName;
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Common.Core.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Common.jQuery.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Common.jQueryPlugins.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Common.Popup.PopupScripts.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Common.Navigation.NavigationScripts.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Common.TouchScrollExtender.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Common.Scrolling.ScrollingScripts.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Ajax.Ajax.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Menu.RadMenuScripts.js", telerikAssembly));

              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Menu.ContextMenu.RadContextMenuScripts.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Input.TextBox.RadInputScript.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Input.DateInput.RadDateInputScript.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Input.NumericTextBox.RadNumericInputScript.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Calendar.RadTimeViewScripts.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Calendar.RadCalendarCommonScript.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Calendar.RadPickersPopupDirectionEnumeration.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Calendar.RadCalendarScript.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Calendar.RadDatePicker.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Calendar.RadDateTimePickerScript.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.ComboBox.RadComboBoxScripts.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.Helpers.DateTime.js", telerikAssembly));

              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.Helpers.ResizeHelper.js", telerikAssembly));

              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.RadSchedulerScripts.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.RecurrenceEditor.RecurrenceEditor.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.ContextMenu.Plugin.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.Scheduling.AdvancedTemplate.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.ClientRendering.BlockCollection.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.ClientRendering.ClientRendering.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.ClientRendering.HorizontalBlockCollection.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.ClientRendering.RenderingManager.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.ClientRendering.ResourceStyleMapping.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.ClientRendering.ResourceStyleMappingCollection.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.RecurrenceRule.RecurrenceRule.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.Views.Week.Model.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.Views.Week.GroupedByResource.Model.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.Views.Week.GroupedByDate.Model.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.Views.MultiDay.Model.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.Views.MultiDay.GroupedByResource.Model.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.Views.MultiDay.GroupedByResource.Model.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.Views.Day.Model.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.Views.Day.GroupedByResource.Model.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.Views.Month.Model.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.Views.Month.GroupedByResource.Model.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.Views.Month.GroupedByDate.Model.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.Views.Timeline.Model.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.Views.Timeline.GroupedByResource.Model.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Scheduler.Views.Timeline.GroupedByDate.Model.js", telerikAssembly));
            
            
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Rating.RadRating.js", telerikAssembly));
             
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Splitter.RadSplitterScripts.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Splitter.RadSlidingZoneScripts.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.PanelBar.RadPanelBarScripts.js", telerikAssembly));
            
            
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.Slider.RadSliderScripts.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.ToolBar.RadToolBarScripts.js", telerikAssembly));
              scriptManager.Scripts.Add(new ScriptReference("Telerik.Web.UI.ListBox.RadListBoxScripts.js", telerikAssembly));
          }

        }

        protected override void OnLoad(EventArgs e)
        {
            base.OnLoad(e);

           
        }

        protected void RadScheduler1_AppointmentInsert(object sender, SchedulerCancelEventArgs e)
        {
            Appointments.Add(new AppointmentInfo(e.Appointment));
        }

        protected void RadScheduler1_AppointmentUpdate(object sender, AppointmentUpdateEventArgs e)
        {
            AppointmentInfo ai = FindById(e.ModifiedAppointment.ID);
            ai.CopyInfo(e.ModifiedAppointment);
        }

        protected void RadScheduler1_AppointmentDelete(object sender, SchedulerCancelEventArgs e)
        {
            Appointments.Remove(FindById(e.Appointment.ID));
        }

        private void InitializeResources()
        {
            ResourceType resType = new ResourceType("User");
            resType.ForeignKeyField = "UserID";

            RadScheduler1.ResourceTypes.Add(resType);
            RadScheduler1.Resources.Add(new Resource("User", 1, "Alex"));
            RadScheduler1.Resources.Add(new Resource("User", 2, "Bob"));
            RadScheduler1.Resources.Add(new Resource("User", 3, "Charlie"));
        }

        private void InitializeAppointments()
        {
            DateTime start = DateTime.UtcNow.Date;
            start = start.AddHours(6);
            Appointments.Add(new AppointmentInfo("Take the car to the service", start, start.AddHours(1), string.Empty, null, new Reminder(30).ToString(),"Asia", 1));
            Appointments.Add(new AppointmentInfo("Meeting with Alex", start.AddHours(2), start.AddHours(3), string.Empty, null, string.Empty, "Asia", 2));

            start = start.AddDays(-1);
            DateTime dayStart = RadScheduler1.UtcDayStart(start);
            Appointments.Add(new AppointmentInfo("Bob's Birthday", dayStart, dayStart.AddDays(1), string.Empty, null, string.Empty, "Asia", 1));
            Appointments.Add(new AppointmentInfo("Call Charlie about the Project", start.AddHours(2), start.AddHours(3), string.Empty, null, string.Empty, "Asia", 2));

            start = start.AddDays(2);
            Appointments.Add(new AppointmentInfo("Get the car from the service", start.AddHours(2), start.AddHours(3), string.Empty, null, string.Empty, "Asia", 1));
        }

        private AppointmentInfo FindById(object ID)
        {
            foreach (AppointmentInfo ai in Appointments)
            {
                if (ai.ID.Equals(ID))
                {
                    return ai;
                }
            }

            return null;
        }
    }
}
